from .main import *

__copyright__    = 'Copyright (C) 2022 tsubasa652'
__version__      = '1.0.0'
__license__      = 'MIT'
__author__       = 'tsubasa652'
__author_email__ = 'mail@tsubasa.ml'
__url__          = 'http://github.com/tsubasa652/python-shortlink-extractor'

__all__ = [extract_short_link]